@@ -81,7 +81,11 @@ function configure_murano_rpc_backend() {
     # TODO(ruhe): get rid of this ugly workaround.
     inicomment $MURANO_CONF_FILE DEFAULT rpc_backend
 
-    iniset $MURANO_CONF_FILE rabbitmq host $RABBIT_HOST
+    if [[ $SERVICE_IP_VERSION == 6 ]]; then
+        iniset $MURANO_CONF_FILE rabbitmq host "$HOST_IPV6"
+    else
+        iniset $MURANO_CONF_FILE rabbitmq host "$HOST_IP"
+    fi
     iniset $MURANO_CONF_FILE rabbitmq login $RABBIT_USERID
     iniset $MURANO_CONF_FILE rabbitmq password $RABBIT_PASSWORD
 
@@ -201,7 +205,7 @@ function configure_murano {
 
     # Setup murano_auth section
     configure_auth_token_middleware $MURANO_CONF_FILE $MURANO_ADMIN_USER $MURANO_AUTH_CACHE_DIR murano_auth
-    iniset $MURANO_CONF_FILE murano_auth auth_uri $KEYSTONE_AUTH_URI
+    iniset $MURANO_CONF_FILE murano_auth www_authenticate_uri  $KEYSTONE_AUTH_URI
 
     configure_murano_rpc_backend
 
@@ -418,9 +422,8 @@ function stop_murano() {
     if [ "$MURANO_USE_UWSGI" == "True" ]; then
         disable_apache_site murano-api
         restart_apache_server
-    else
-        stop_process murano-api
     fi
+    stop_process murano-api
     stop_process murano-engine
 }
 
@@ -496,7 +499,7 @@ function configure_murano_tempest_plugin() {
 # - configure_murano_dashboard
 # - cleanup_murano_dashboard
 
-source $TOP_DIR/lib/horizon
+. $TOP_DIR/lib/horizon
 
 # Defaults
 # --------
@@ -574,7 +577,6 @@ function configure_local_settings_py() {
     sed -e "s%\(^\s*MURANO_REPO_URL\s*=\).*$%\1 '$MURANO_REPOSITORY_URL'%" -i $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
     sed -e "s%\(^\s*'NAME':\).*$%\1 os.path.join('$MURANO_DASHBOARD_DIR', 'openstack-dashboard.sqlite')%" -i $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
     echo -e $"\nMETADATA_CACHE_DIR = '$MURANO_DASHBOARD_CACHE_DIR'" | sudo tee -a $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
-    echo -e $"\nGLARE_API_URL = '$GLANCE_SERVICE_PROTOCOL://$GLANCE_GLARE_HOSTPORT'" | sudo tee -a $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
 
 }
 
